gpe package
===========

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   gpe.univ

Submodules
----------

gpe.evolution module
--------------------

.. automodule:: gpe.evolution
   :members:
   :undoc-members:
   :show-inheritance:

gpe.gpe module
--------------

.. automodule:: gpe.gpe
   :members:
   :undoc-members:
   :show-inheritance:

gpe.IO module
-----------------

.. automodule:: gpe.IO
   :members:
   :undoc-members:
   :show-inheritance:

gpe.set\_device module
----------------------

.. automodule:: gpe.set_device
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: gpe
   :members:
   :undoc-members:
   :show-inheritance:
